// *******************************************************************
// M_HOME04.POV                                              12 Nov 00
// Modernist_Home:  interior east from front door:
// *******************************************************************

#version 3.1;

// *******************************************************************
// Control Variables: 
//     turning some of these off = many "2 objs in csg" messages
// *******************************************************************

#declare ShowDetails = 1;    // 0=minimum detail, 1=full detail 
#declare GridOn      = 0;    // 0=off, 1=on
#declare ShowLights  = 0;    // 0=day, 1=night
#declare ShowFloor   = 1;    // 0=no, 1=yes
#declare ShowGlass   = 1;    // 0=no, 1=yes
#declare ShowArch    = 1;    // 0=no, 1=yes
#declare DoorOpen    = 0;    // 0=closed, 1=open

#include "m_home00.inc"      // declarations specific to Modernist_House

global_settings { assumed_gamma 1.0 }

// *******************************************************************
// Define Ambient Lights                                             
// *******************************************************************

#declare LightLocate = < 140, 150, -190 >;
#declare intensity = 1;

#if ( ShowDetails = 1 )
//   light_source { LightLocate  color White }
   light_source {
      0*x                              // position (translated below)
      color rgb 1.0                    // color
      area_light < 2,0,0 > < 0,0,2 >   // light's spread
      2, 2                             // total number of lights
      adaptive 0                       // 0,1,2,3... 
      jitter                           // random softening
      translate LightLocate            // location of light
             } // end area light
#else
   light_source { LightLocate  color White }
#end

// *******************************************************************
// Define Sky                                                        
// *******************************************************************

#if ( ShowDetails = 0 )
   background { color LightBlue }      // day
#else
   sky_sphere { pigment { Bright_AquaBlue4  
                          scale < 65, 2, 15 >
                        }//end pigmnt
              } //end day sky
   background { color LightBlue }  // temp test
#end

// *******************************************************************
// Define Camera
// *******************************************************************

#declare Beauty_Shot =
camera {
   direction < 0, 0, 7 >
   location  < -5, 6, -200 >        // SW of center
   look_at   < 0, 6, 0 > }      

#declare Camera_SW =
camera {
   direction < 0, 0, 2 >
   location  < -20, 6, 4 >          // SW of center
   look_at   < 20, 5, 16 > }             //eye level

#declare Camera_SE =
camera {
   direction < 0, 0, 4 >
   location  < 100, 50, -200 >         // SE of center
   look_at   < 0, 0, 0 > }

#declare Camera_South =
camera {
   direction < 0, 0, 2.5 >
   location  < 0, 5, -75 >          // south of cntr
   look_at   < 3.5, 5,    0 > }

#declare Camera_West =
camera {
   direction <    0, 0, 12 >
   location  < -300, 0, 0 >          // west
   look_at   <    0, 0, 0 > }

#declare Camera_East =
camera {
   direction <   0, 0, 2 >
   location  < 300, 5, 0 >           // East
   look_at   <   0, 5, 0 > }

#declare Camera_Above =
camera {
   direction < 0,   0, 4 >
   location  < 0, 500, 0 >             // Above: dir 2, +200y
   look_at   < 0,   0, 0.1 > }           //  shows 150x 100z area

#declare Camera_Quarter =
camera { 
   direction < 0, 0, 8 >
   location  < -140, 100, -240 >       // SW and above 
   look_at   < 0, 0, 0 > }             // center of scene

// *******************************************************************
//  Define Test Scene:
// *******************************************************************

// CAMERA:
#declare MoveX = 0;
#declare MoveY = 0;
#declare MoveZ = 0;
//camera { Beauty_Shot    translate < MoveX, MoveY, MoveZ > }
camera { Camera_SW      translate < MoveX, MoveY, MoveZ > }
//camera { Camera_SE      translate < MoveX, MoveY, MoveZ > }
//camera { Camera_South   translate < MoveX, MoveY, MoveZ > }
//camera { Camera_West    translate < MoveX, MoveY, MoveZ > }
//camera { Camera_East    translate < MoveX, MoveY, MoveZ > }
//camera { Camera_Above   translate < MoveX, MoveY, MoveZ > }
//camera { Camera_Quarter translate < MoveX, MoveY, MoveZ > }

// FLOOR:
object { Clip_Floor }
//object { Test_Floor }

// *******************************************************************
// III.  DEFINE  Modernist_Home:
// *******************************************************************

// **************************************************************
//       B.  North Room:
// **************************************************************

//    DEFINE  the North Room:
#declare North_Room =
union {
   //roof:
   object { North_Roof }// roof                            
   //chimneys:
   object { North_Chimneys }

   //north wall:
   object { N_North_Frame_Up  translate <   0.0, 16, 17 > } //1st floor
   object { N_North_Panel_Up  translate <   5.0, 16, 17 > } //1st floor
   object { N_North_Frame_Dn  translate < -12.5,  6, 17 > } //ground
   object { N_North_Panel_Dn  translate < -12.5,  6, 17 > } //ground
   //south wall:
   object { N_South_Frame_East  translate <    20, 16, -17.5 > } //1st floor
   object { N_South_Frame_West  translate < -17.5, 16, -17.5 > } //1st floor
   object { N_South_Frame_East  translate <    20,  6, -17.5 > } //ground
   object { N_South_Frame_West  translate < -17.5,  6, -17.5 > } //ground
   object { N_South_Panel       translate <   -21,  6, -17.5 > } //both  
   object { N_South_Frame_Center  translate < 0, 16, -7.5 > } //1st floor
   object { N_South_Panel_Center  translate < 0, 16, -7.5 > } //1st floor

   //west wall:
   object { N_West_Frame  translate < -25, 16, 0 > } //1st floor
   object { N_West_Panel  translate < -25, 16, 12.5 > } //both floors
   object { N_West_Frame  translate < -25,  6, 0 > } //ground floor

   //east wall:
   object { N_East_Frame  translate < 35, 16, -12.5 > } //1st floor
   object { N_East_Panel  translate < 35, 16,  12.5 > } //1st floor

   //doors:
   object { M_Front_Door rotate y*180 translate < 5, 6, 17 > }//north door
   object { M_Front_Door  translate < 0, 6, -7.5 > }//south door
//   object { DoorA1_Closed rotate y*90  translate < -25, 5, 12.5 > } //west

   // floor:
   #if ( ShowFloor = 1 )
      object { Build_Block_1           // 1st floor  center
               texture { Tan_Tex }
               scale < 20, 0.5, 25 >
               translate < 0, 10.5, 5 >
             }// end 1st floor center
      object { Build_Block_1           // 1st floor  west
               texture { Tan_Tex }
               scale < 16, 0.5, 35 >
               translate < -17, 10.5, 0 >
             }// end 1st floor west
      object { Build_Block_1           // 1st floor east
               texture { Tan_Tex }
               scale < 25, 0.5, 35 >
               translate < 22.5, 10.5, 0 >
             }// end 1st floor east
      object { Build_Block_1           // ground floor    
               texture { Brown_Tex }
               scale < 61, 1, 36 >  
               translate < 5, 0.5, 0 >
             }// end north ground floor
   #end // show floor?
      } // end north room union

// **************************************************************
// **************************************************************
//       C.  East Room:
// **************************************************************

//    DEFINE East Wing:
#declare East_Room =
union {

#if ( ShowDetails = 0 ) //show minimum
   //walls:
   object { E_South_Frame  translate < 28.5, 6,    31 > }//n
   object { E_South_Frame  translate < 28.5, 6, -39.5 > }//s
   object { E_East_Frame   translate < 46.0, 6, -34.5 > }
   object { E_West_Frame   translate < 10.5, 6,     6 > }
#else  //show maximum
   //roof:
   object { East_Roof }
/*
   object { Railing_Section_A ( 1.5, 0.25, 22 )
            rotate y*90  translate < 46, 12.5,  30 > } //east 
   object { Railing_Section_A ( 1.5, 0.25, 9 )
                         translate < 14, 12.5,  30 > } //north
   object { Railing_Section_A ( 1.5, 0.25, 9 )
                         translate < 14, 12.5, -40 > } //south
*/

   //walls:
   object { E_South_Frame  translate < 28.5, 6,  31.0 > }//n side
   object { E_South_Frame  translate < 28.5, 6, -39.5 > }//s side
   object { E_East_Frame   translate < 46.0, 6, -34.5 > }
   object { E_West_Frame   translate < 10.5, 6,   6.0 > }
   object { E_South_Panel  translate < 28.5, 6,  31.0 > }//n side
   object { E_South_Panel  translate < 28.5, 6, -39.5 > }//s side
   object { E_East_Panel   translate < 46.0, 6,  -5.0 > }
#end  //of show all details?

   //floor:
#if ( ShowFloor = 1 )
   object { Build_Block_1              
            texture { Brown_Tex }
            scale < 37, 1, 73 >
            translate < 28.5, 0.5, -4 >
          }// end east floor
#end //if showfloor
      } // end east room union

// **************************************************************
// **************************************************************
//       D.  West Room: 
// **************************************************************

//    DEFINE West Wing:
#declare West_Room =
union {

#if ( ShowDetails = 0 )
   //walls:
   object { W_North_Frame  translate < -42.5, 6,  -5 > }
   object { W_South_Frame  translate < -42.5, 6, -35 > }
   object { W_West_Frame   translate <   -60, 6, -20 > }
   object { W_East_Frame   translate <   -25, 6, -20 > }
#else
   //roof:
   object { West_Roof  translate < -43.5, 11, -20 > }
   //walls:
   object { W_North_Frame  translate < -42.5, 6,  -5 > }
   object { W_South_Frame  translate < -42.5, 6, -35 > }
   object { W_West_Frame   translate <   -60, 6, -20 > }
   object { W_East_Frame   translate <   -25, 6, -20 > }
   object { W_North_Panel  translate < -36.5, 6,  -5 > }
   object { W_South_Panel  translate < -42.5, 6, -35 > }
   object { W_West_Panel   translate <   -60, 6, -20 > }
   object { W_East_Panel   translate <   -25, 6, -25 > }
   //door:
//   object { M_Front_Door  translate < -50, 4, 0 > }
   //floor:
#end  // of show details?

   //kitchen:
//   object { W_Kitchen  translate < -42.5, 1, -20 > }

#if ( ShowFloor = 1 )
   object { Build_Block_1
            texture { Brown_Tex }
            scale < 36, 1, 31 >        
            translate < -42.5, 0.5, -20 >
          }// end west floor
#end //show floor?

      } // end west room union

// *******************************************************************
//       F.  Our_House in the Modernist/International style:
// *******************************************************************

//    DEFINE the whole building and setting:
#declare Modernist_Home =
union {

   object { North_Room }
   object { East_Room }
   object { West_Room }

   object { Front_SideWalk
            translate < 0, 0, -30 > }

   object { Arched_Hall_1
            translate < 0, 5, -30 >
          }// end arched hallway
/*
   object { Planter_Box_2  translate < -17, 1, -24 > }
   object { 
      box {< -5.5, -0.5, -5.5 > < 5.5, 0.5, 5.5 >
           pigment { VeryDarkBrown } }
      translate < -17, 1, -24 >
          }// end generic dirt
*/
      } // end union modernist house

// ************************************************************** 
// **************************************************************


object { Modernist_Home }


// **************************************************************

//object { Man01  translate < 1, 3.5, -20 > }
//object { X_Axis }
//object { Z_Axis }

// **************************************************************

#if ( GridOn = 1 )
//   object { Grid10XY } // vert rods
//   object { Grid10XZ } // horz rods  centered
//   object { Grid10XZ  translate < -10, 0,  10 > } // nw
//   object { Grid10XZ  translate <  10, 0, -10 > } // se
//   object { Grid5XY } // vert balls
//   object { Mark01  translate < 0, 0, 0 > } // center

   //centered y,z:
   object { Mark01  translate <   0, 0, 0 > } // center
   object { Mark01  translate <  10, 0, 0 > } // 10x apart
   object { Mark01  translate < -10, 0, 0 > } //    "
   object { Mark01  translate <  20, 0, 0 > } //        
   object { Mark01  translate < -20, 0, 0 > } //    "
   object { Mark01  translate <  30, 0, 0 > } // 
   object { Mark01  translate < -30, 0, 0 > } //    "
   object { Mark01  translate <  40, 0, 0 > } // 
   object { Mark01  translate < -40, 0, 0 > } //    "
   object { Mark01  translate <  50, 0, 0 > } // 
   object { Mark01  translate < -50, 0, 0 > } //    "

   //south -50z
   object { Mark01  translate <   0, 0, -50 > } // center
   object { Mark01  translate <  10, 0, -50 > } // 10x apart
   object { Mark01  translate < -10, 0, -50 > } //    "
   object { Mark01  translate <  20, 0, -50 > } //        
   object { Mark01  translate < -20, 0, -50 > } //    "
   object { Mark01  translate <  30, 0, -50 > } // 
   object { Mark01  translate < -30, 0, -50 > } //    "
   object { Mark01  translate <  40, 0, -50 > } // 
   object { Mark01  translate < -40, 0, -50 > } //    "
   object { Mark01  translate <  50, 0, -50 > } // 
   object { Mark01  translate < -50, 0, -50 > } //    "

   object { Mark01  translate < 0, 0,  10 > } // 10z apart
   object { Mark01  translate < 0, 0, -10 > } //    "
   object { Mark01  translate < 0, 0,  20 > } //        
   object { Mark01  translate < 0, 0, -20 > } //    "
   object { Mark01  translate < 0, 0,  30 > } // 
   object { Mark01  translate < 0, 0, -30 > } //    "
   object { Mark01  translate < 0, 0,  40 > } // 
   object { Mark01  translate < 0, 0, -40 > } //    "
   object { Mark01  translate < 0, 0,  50 > } // 
   object { Mark01  translate < 0, 0, -50 > } //    "

   //west -50x
   object { Mark01  translate < -50, 0,  10 > } // 10z apart
   object { Mark01  translate < -50, 0, -10 > } //    "
   object { Mark01  translate < -50, 0,  20 > } //        
   object { Mark01  translate < -50, 0, -20 > } //    "
   object { Mark01  translate < -50, 0,  30 > } // 
   object { Mark01  translate < -50, 0, -30 > } //    "
   object { Mark01  translate < -50, 0,  40 > } // 
   object { Mark01  translate < -50, 0, -40 > } //    "
   object { Mark01  translate < -50, 0,  50 > } // 
   object { Mark01  translate < -50, 0, -50 > } //    "

#end 

// *******************************************************************
//    STORAGE:
// *******************************************************************

/*

*/

// *******************************************************************
// *******************************************************************
//    Michael Brendan Hurley, SDE, Ltd.                   Fall 2000
// *******************************************************************
